<?php
/**
 * Pocket Project
 * 
 * @copyright 2006 Power-Station co., Ltd, ALL Rights Reserved,
 */

/**
 *  ユーザエージェント判定クラス
 *
 *  @author     Shogo Minami
 *  @access     public
 *  @package    Pocket
 */
class UAJudgment
{
    var $is_mobile = false;
    var $is_docomo = false;
    var $is_vodafone = false;
    var $is_au = false;
    var $is_willcom = false;

    /**
     *  コンストラクタ
     *
     *  @access public
     *  @param  array   $server             サーバ変数配列
     */
    function UAJudgment($server = null)
    {
        if (is_null($server))
        {
            $server = $_SERVER;
        }
        $this->classify($server);
    }

    /**
     *  User-Agent の値からキャリアを判別
     *
     *  @access public
     *  @param  array   $server             サーバ変数配列
     */
    function classify($server)
    {
        $ua = $server['HTTP_USER_AGENT'];

        // DoCoMo
        if (!strncmp($ua, 'DoCoMo', 6))
        {
            $this->is_docomo = true;
            $this->is_mobile = true;
        }
        // Vodafone(PDC)
        elseif (!strncmp($ua, 'J-PHONE', 7))
        {
            $this->is_vodafone = true;
            $this->is_mobile = true;
        }
        // Vodafone(3G)
        // Up.Browser を搭載しているものがある(auより先に評価)
        elseif (!strncmp($ua, 'Vodafone', 8)
            || !strncmp($ua, 'SoftBank', 8)
            || !strncmp($ua, 'MOT', 3))
        {
            $this->is_vodafone = true;
            $this->is_mobile = true;
        }
        // au
        elseif (!strncmp($ua, 'KDDI', 4)
            || !strncasecmp($ua, 'UP.Browser', 10))
        {
            $this->is_au = true;
            $this->is_mobile = true;
        }
        // WILLCOM/DDIPOCKET
        elseif (strpos($ua, 'WILLCOM') !== false
            || strpos($ua, 'DDIPOCKET') !== false)
        {
            $this->is_willcom = true;
            $this->is_mobile = true;
        }
        // 上記以外
        else
        {
            $this->is_mobile = false;
        }
    }

    /**
     *  携帯端末か判別
     *
     *  @access public
     */
    function isMobile() { return $this->is_mobile; }

    /**
     *  DoCoMo端末か判別
     *
     *  @access public
     */
    function isDocomo() { return $this->is_docomo; }

    /**
     *  Vodafone端末か判別
     *
     *  @access public
     */
    function isVodafone() { return $this->is_vodafone; }

    /**
     *  au端末か判別
     *
     *  @access public
     */
    function isAu() { return $this->is_au; }

    /**
     *  WILLCOM/DDIPOCKET端末か判別
     *
     *  @access public
     */
    function isWillcom() { return $this->is_willcom; }
}

?>
